"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRepository = exports.UserRepository = void 0;
const utils_1 = require("../../methods/utils");
const model_1 = require("../model");
const tokenRepository_1 = require("./tokenRepository");
const service_common_1 = require("@crosslab/service-common");
const bcryptjs_1 = require("bcryptjs");
class UserRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('User');
    }
    initialize(AppDataSource) {
        this.repository = AppDataSource.getRepository(model_1.UserModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.tokens = [];
        model.roles = [];
        return model;
    }
    async write(model, data) {
        if (data.username)
            model.username = data.username;
        if (data.password)
            model.password = await (0, bcryptjs_1.hash)(data.password, 10);
    }
    async format(model) {
        return {
            url: (0, utils_1.userUrlFromId)(model.uuid),
            id: model.uuid,
            username: model.username,
        };
    }
    async remove(model) {
        if (!this.repository)
            this.throwUninitializedRepositoryError();
        for (const tokenModel of model.tokens) {
            await tokenRepository_1.tokenRepository.remove(tokenModel);
        }
        await this.repository.remove(model);
    }
    addRoleModelToUserModel(userModel, roleModel) {
        if (!userModel.roles.find((role) => role.uuid === roleModel.uuid)) {
            userModel.roles.push(roleModel);
        }
    }
    removeRoleModelFromUserModel(userModel, roleModel) {
        let index = userModel.roles.findIndex((role) => role.uuid === roleModel.uuid);
        while (index !== -1) {
            userModel.roles.splice(index, 1);
            index = userModel.roles.findIndex((role) => role.uuid === roleModel.uuid);
        }
    }
    getDefaultFindOptionsRelations() {
        return {
            roles: {
                scopes: true,
            },
            tokens: true,
        };
    }
}
exports.UserRepository = UserRepository;
exports.userRepository = new UserRepository();
//# sourceMappingURL=userRepository.js.map