#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const dataSource_1 = require("./database/dataSource");
const activeKeyRepository_1 = require("./database/repositories/activeKeyRepository");
const generated_1 = require("./generated");
const allowlist_1 = require("./methods/allowlist");
const api_1 = require("./methods/api");
const key_1 = require("./methods/key");
const service_common_1 = require("@crosslab/service-common");
async function startAuthenticationService(appConfig, options) {
    await dataSource_1.AppDataSource.initialize(options);
    await (0, dataSource_1.initializeDataSource)();
    api_1.apiClient.accessToken = appConfig.API_TOKEN;
    const allowlist = appConfig.ALLOWLIST ? (0, allowlist_1.parseAllowlist)(appConfig.ALLOWLIST) : [];
    // Resolve Allowlist
    await (0, allowlist_1.resolveAllowlist)(allowlist);
    setInterval(allowlist_1.resolveAllowlist, 600000, allowlist);
    // Create new active key
    const activeSigKey = await activeKeyRepository_1.activeKeyRepository.findOne({
        where: {
            use: 'sig',
        },
    });
    const key = activeSigKey?.key ?? (await (0, key_1.generateNewKey)());
    const jwks = JSON.stringify({ keys: [(0, key_1.jwk)(key)] });
    if (!activeSigKey) {
        const activeKeyModel = await activeKeyRepository_1.activeKeyRepository.create({
            use: key.use,
            key: key.uuid,
        });
        await activeKeyRepository_1.activeKeyRepository.save(activeKeyModel);
    }
    generated_1.app.get('/.well-known/jwks.json', (_req, res) => {
        res.send(jwks);
    });
    generated_1.app.get('/.well-known/openid-configuration', (_req, res) => {
        res.send({ jwks_uri: '/.well-known/jwks.json' });
    });
    generated_1.app.get('/auth/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    generated_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(appConfig),
        },
    });
    generated_1.app.listen(appConfig.PORT);
    console.log('Authentication Service started successfully');
}
/* istanbul ignore if */
if (require.main === module) {
    startAuthenticationService(config_1.config, config_1.dataSourceConfig);
}
//# sourceMappingURL=index.js.map