"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllowlistedUser = exports.resolveAllowlistEntry = exports.resolveAllowlist = exports.parseAllowlist = exports.allowlist = void 0;
const service_common_1 = require("@crosslab/service-common");
const userRepository_1 = require("../database/repositories/userRepository");
const errors_1 = require("../types/errors");
exports.allowlist = {};
function parseAllowlist(allowlistToParse) {
    const removedWhitespaceAllowlist = allowlistToParse.replace(/\s+/g, '');
    const rawEntries = removedWhitespaceAllowlist.split(",");
    const entries = rawEntries.map((rawEntry) => {
        const splitRawEntry = rawEntry.split(':');
        if (splitRawEntry.length !== 3) {
            throw new errors_1.MalformedAllowlistError(`The allowlist is malformed`);
        }
        return {
            token: splitRawEntry[0],
            username: `${splitRawEntry[1]}:${splitRawEntry[2]}`,
        };
    });
    return entries;
}
exports.parseAllowlist = parseAllowlist;
async function resolveAllowlist(allowlistEntries) {
    for (const entry of allowlistEntries) {
        try {
            const result = await resolveAllowlistEntry(entry);
            exports.allowlist[result[0]] = result[1];
        }
        catch (error) {
            console.error(error);
        }
    }
}
exports.resolveAllowlist = resolveAllowlist;
/**
 * This function tries to resolve an entry of the allowlist.
 * @param allowlistEntry Entry of the allowlist ("url":username") to be resolved.
 * @returns Resolved entry in the form "ip:username"
 */
async function resolveAllowlistEntry(allowlistEntry) {
    console.log(`resolveAllowlistEntry called`);
    // Search the user with the provided username
    const userModel = await userRepository_1.userRepository.findOne({
        where: {
            username: allowlistEntry.username,
        },
    });
    if (!userModel)
        throw new service_common_1.MissingEntityError(`Could not find user ${allowlistEntry.username}`);
    console.log(`resolveAllowlistEntry succeeded`);
    return [allowlistEntry.token, userModel.username];
}
exports.resolveAllowlistEntry = resolveAllowlistEntry;
/**
 * Try to find user associated to allowlisted IP.
 * @param token IP from the client that is potentially allowlisted.
 * @throws {MissingEntityError} User associated with allowlisted IP needs to exist in the database.
 * @returns The user associated with the allowlisted IP.
 */
async function getAllowlistedUser(token) {
    console.warn(`trying to find allowlisted user ${exports.allowlist[token]}`);
    const user = exports.allowlist[token]
        ? await userRepository_1.userRepository.findOne({
            where: {
                username: exports.allowlist[token],
            },
        })
        : undefined;
    if (!user)
        throw new service_common_1.MissingEntityError(`User ${exports.allowlist[token]} is not in the database`, 500);
    return user;
}
exports.getAllowlistedUser = getAllowlistedUser;
//# sourceMappingURL=allowlist.js.map