"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDevice = exports.apiClient = void 0;
const api_client_1 = require("@cross-lab-project/api-client");
const errors_1 = require("../types/errors");
const api_client_2 = require("@cross-lab-project/api-client");
const config_1 = require("../config");
exports.apiClient = new api_client_2.APIClient(config_1.config.BASE_URL);
/**
 * This function wraps the getDevice() of the api-client and throws server-specific errors.
 * @param deviceUrl The url of the requested device.
 * @throws {InternalRequestError} Thrown when an error occurs during the request.
 * @returns The requested device.
 */
async function getDevice(deviceUrl) {
    try {
        const device = await exports.apiClient.getDevice(deviceUrl);
        return device;
    }
    catch (error) {
        if (error instanceof api_client_1.FetchError)
            throw new errors_1.InternalRequestError(`An error occurred while trying to fetch the device`, error, 500);
        else if (error instanceof api_client_1.ValidationError)
            throw new errors_1.InternalRequestError(`An error occurred while trying to validate the request/response`, error, 500);
        else if (error instanceof api_client_1.InvalidUrlError)
            throw new errors_1.InternalRequestError(`The provided device url is malformed`, error, 400);
        else if (error instanceof api_client_1.UnsuccessfulRequestError)
            throw new errors_1.InternalRequestError(`The request was unsuccessful`, error, error.response.status);
        else
            throw error;
    }
}
exports.getDevice = getDevice;
//# sourceMappingURL=api.js.map