"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jwk = exports.generateNewKey = void 0;
const jose_1 = require("jose");
const keyRepository_1 = require("../database/repositories/keyRepository");
/**
 * This function generates a new key.
 * @param usage The usage of the key (default: "sig")
 * @returns The newly generated key.
 */
async function generateNewKey(usage = 'sig') {
    const keyPair = await (0, jose_1.generateKeyPair)('RS256');
    const keyModel = await keyRepository_1.keyRepository.create({
        private_key: await (0, jose_1.exportJWK)(keyPair.privateKey),
        public_key: await (0, jose_1.exportJWK)(keyPair.publicKey),
        use: usage,
        alg: 'RS256',
    });
    await keyRepository_1.keyRepository.save(keyModel);
    return keyModel;
}
exports.generateNewKey = generateNewKey;
/**
 * This function parses a JWK from the provided key.
 * @param keyModel The key to be parsed.
 * @returns The parsed JWK.
 */
function jwk(keyModel) {
    const parsed_jwk = keyModel.public_key;
    parsed_jwk.use = keyModel.use;
    parsed_jwk.alg = keyModel.alg;
    parsed_jwk.kid = keyModel.uuid;
    return parsed_jwk;
}
exports.jwk = jwk;
//# sourceMappingURL=key.js.map